'--------------------------------------------------------------------
'Quellprogramm: QUAT1.BAS
'--------------------------------------------------------------------
'Das Programm berechnet die Julia-Menge mit Quaternionen
'fuer die Iteration q(n+1) = q(n)^2 + c
'nach dem Level-Set-Algorithmus.
'Die z-Komponente wird mit Hoehenlinien dargestellt.
'--------------------------------------------------------------------
'Eingabewerte:
a = -1: b = 0             'Parameter c = (a,b)
nmax = 15                 'Anzahl der Iterationen nmax
'--------------------------------------------------------------------

SCREEN 12                 'VGA, 640 x 480 Pixel, 16 Farben
px = 400: py = 400        'Bildschirmbereich

'q-Raum                   'mathematischer Bereich
xmin = -2: xmax = 2
ymin = -2: ymax = 2
zmin = 0: zmax = 1

xschritt = (xmax - xmin) / px       'Schrittweite
yschritt = (ymax - ymin) / py
zschritt = .02

CLS

'Berechnung der Julia-Menge durch Abtasten der
'Bildschirmpunkte mit Test auf Mengenzugehrigkeit
FOR sx = 0 TO px                   'x-Komponente (Bildschirmspalten)
   x = xmin + sx * xschritt
   FOR zy = 0 TO py                'y-Komponente (Bildschirmzeilen)
      y = ymax - zy * yschritt
      FOR z = zmin TO zmax STEP zschritt      'z-Komponente
         x1 = x: y1 = y: z1 = z
         FOR n = 1 TO nmax         'Iterationsschleife
            xx = x1 * x1 - y1 * y1 - z1 * z1 + a
            y1 = 2 * x1 * y1 + b
            z1 = 2 * x1 * z1
            x1 = xx
            IF x1 * x1 + y1 * y1 + z1 * z1 > 16 THEN EXIT FOR
         NEXT n
         IF x1 * x1 + y1 * y1 + z1 * z1 <= 16 THEN
            'Darstellung der z-Komponente durch Hoehenlinien
            FOR i = 0 TO 10
               IF z >= i * .1 AND z < (i + 1) * .1 THEN
                  'Punktausgabe
                  PSET (sx, zy), 3 + i
                  EXIT FOR
               END IF
            NEXT i
         END IF
      NEXT z
   NEXT zy
NEXT sx

PRINT "c-Parameter:"
PRINT "("; a; ","; b; ")"

END



